package com.mdd.admin.controller.log;

import com.mdd.admin.aop.Log;
import com.mdd.admin.service.ICodeLogService;
import com.mdd.admin.validate.commons.IdValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.log.CodeLogSearchValidate;
import com.mdd.admin.validate.log.CodeLogUpdateValidate;
import com.mdd.admin.vo.CodeLogDetailVo;
import com.mdd.admin.vo.CodeLogListedVo;
import com.mdd.common.aop.NotPower;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/codeLog"})
@Api(
   tags = {"验证码记录管理"}
)
public class CodeLogController {
   @Resource
   ICodeLogService iCodeLogService;

   @NotPower
   @PostMapping({"/list"})
   @ApiOperation("验证码记录列表")
   public AjaxResult<PageResult<CodeLogListedVo>> list(@Validated PageValidate pageValidate, @Validated @RequestBody CodeLogSearchValidate searchValidate) {
      PageResult<CodeLogListedVo> list = this.iCodeLogService.list(pageValidate, searchValidate);
      return AjaxResult.success(list);
   }

   @NotPower
   @GetMapping({"/detail"})
   @ApiOperation("验证码记录详情")
   public AjaxResult<CodeLogDetailVo> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      CodeLogDetailVo detail = this.iCodeLogService.detail(id);
      return AjaxResult.success(detail);
   }

   @NotPower
   @Log(
      title = "验证码记录编辑"
   )
   @PostMapping({"/edit"})
   @ApiOperation("验证码记录编辑")
   public AjaxResult<Object> edit(@Validated @RequestBody CodeLogUpdateValidate updateValidate) {
      this.iCodeLogService.edit(updateValidate);
      return AjaxResult.success();
   }

   @Log(
      title = "验证码记录删除"
   )
   @PostMapping({"/del"})
   @ApiOperation("验证码记录删除")
   public AjaxResult<Object> del(@Validated @RequestBody IdValidate idValidate) {
      this.iCodeLogService.del(idValidate.getId());
      return AjaxResult.success();
   }
}
